@@ -297,19 +297,13 @@ mod codspeed {
     ) {
         let (uri, bench_name) = create_uri_and_name(id, c);
 
-        #[cfg(unix)]
+        if let Err(error) =
+            ::codspeed::instrument_hooks::InstrumentHooks::instance().set_executed_benchmark(&uri)
         {
-            if let Err(error) =
-                ::codspeed::fifo::send_cmd(codspeed::fifo::Command::CurrentBenchmark {
-                    pid: std::process::id(),
-                    uri: uri.clone(),
-                })
+            if ::codspeed::utils::running_with_codspeed_runner()
+                && ::codspeed::utils::is_perf_enabled()
             {
-                if codspeed::utils::running_with_codspeed_runner()
-                    && codspeed::utils::is_perf_enabled()
-                {
-                    eprintln!("Failed to send benchmark URI to runner: {error:?}");
-                }
+                eprintln!("Failed to set executed benchmark URI: {error:?}");
             }
         }
 
